#
# spec file for package ksmbd-tools
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ksmbd-tools
Version:        3.5.3
Release:        1.1
Summary:        ksmbd kernel server userspace utilities
License:        GPL-2.0-or-later
Group:          System/Filesystems
URL:            https://github.com/cifsd-team/ksmbd-tools
Source:         https://github.com/cifsd-team/ksmbd-tools/archive/refs/tags/%{version}.tar.gz

BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  glib2-devel
BuildRequires:  libnl3-devel
BuildRequires:  libtool
# ksmbd kernel module was only added in kernel 5.15
Requires:       kmod(ksmbd.ko)

%description
Set of utilities for creating and managing SMB3 shares for the ksmbd kernel
module.

%prep
%autosetup -p1

%build
./autogen.sh
%configure --with-systemdsystemunitdir=%{_unitdir}
%make_build

%install
%make_install
# example conf file is packaged as documentation
rm -f %{buildroot}/%{_sysconfdir}/ksmbd/ksmbd.conf.example

%pre
%service_add_pre ksmbd.service

%post
%service_add_post ksmbd.service

%preun
%service_del_preun ksmbd.service

%postun
%service_del_postun ksmbd.service

%files
%{_sbindir}/*
%{_libexecdir}/ksmbd.tools
%{_unitdir}/ksmbd.service
%dir %{_sysconfdir}/ksmbd
%doc ksmbd.conf.example
%{_mandir}/man8/*
%{_mandir}/man5/*

%changelog
* Thu Dec  5 2024 David Disseldorp <ddiss@suse.com>
- Update to version 3.5.3
  * Fix adduser / addshare prompting on musl libc
  * Fix use of `veto files` as global share parameter
  * Lookup primary group and don't recurse in ksmbd.conf @group handling
  * Fix a leak and an intermittent auth failure in Kerberos 5
  * Add global parameter `kerberos support`
  * Fix intermittent `ksmbd.control --list` failure
  * Fix potential UAFs on mountd shutdown
  * Use supplementary groups on filesystem access
  * Document long-standing duplicate key-value quirk
  * Log ignored key-values
  * Have only one of `read only`, `writeable`, etc. take effect on share
  * Allow ASCII tab in user names and share names
  * Invalidate share / server if certain parameters fail to take effect
  * Increase minimum GLib version to 2.58
  * Fix man page formatting issues
* Sat Apr  6 2024 David Disseldorp <ddiss@suse.com>
- Update to version 3.5.2
  * Add durable handles parameter to ksmbd.conf.
  * Add payload_sz in ksmbd_share_config_response to validate ipc response.
  * Fix UAF and cleanups.
- Update to version 3.5.1
  * Fix worker_init_sa_handler return type.
  - Drop ksmbd-tools-fix-worker_init_sa_handler-return-type.patch
  * Don't add global default `read only = yes'.
    Shares are still read-only by default.
* Tue Oct 31 2023 David Disseldorp <ddiss@suse.com>
- Update to version 3.5.0
  * Fix potencial NULL deference errors.
  * Improved and cleaned up incorrect Glib library usage.
  * Fix memleak and several bugs.
  * Replace std functions with glib ones.
  * update manpages.
  * Improve the validation of ksmbd-tools's files(subauth, pwddb, conf).
  * Increase the minimum glib version(2.40 -> 2.44)
  * Several clean-ups.
  * Add --list option to ksmbd.control.
- Add ksmbd-tools-fix-worker_init_sa_handler-return-type.patch
* Thu Jul 27 2023 David Disseldorp <ddiss@suse.com>
- Update to version 3.4.9:
  * Fix handling of max connections on config reload.
  * Add a crossmnt parameter in smb.conf.
- Remove unnecessary kernel-default BuildRequires
- Add explicit --with-systemdsystemunitdir %%configure parameter
* Sun Apr  9 2023 David Disseldorp <ddiss@suse.com>
- Update to version 3.4.8:
  * Fix memleaks.
  * Fix two security issues that were reported by ZDI.
* Sun Mar 19 2023 David Disseldorp <ddiss@suse.com>
- Update to version 3.4.7:
  * add max connections for global section.
  * default max connections is changed to 128 from no limitation.
  * build utilities as a single binary.
  * fix several bugs and memleak, and clean-ups.
  * use 'disabled', 'auto' and 'mandatory' for smb3 encryption parameter.
  * fix guest account bugs.
- 3.4.6:
  * Add meson build.
  * Several clean-up and bug fixes.(leak, segfault, debug print, typo, etc)
  * Improve usage strings and argument handling.
  * Support --sysconfdir and --with-rundir(or -Drundir) options for configure
    or meson.(See the README for details.)
  * Fix password prompting for ksmbd.adduser.
  * Notify ksmbd of all commands of ksmbd.addshare and ksmbd.addshare.
  * Inform ksmbd of stale share config.
  * Fix passworkd prompting issues on ksmbd.adduser.
  * Add manpages for all utils and ksmbd.conf.
  * Rename smb.conf to ksmbd.conf.
  * Set netlink socket's receive buffer size to 1 MiB
  * Add @group support to ksmbd.conf for lists of users.
  * Casefold utf-8 share names.
- 3.4.5:
  * Add support for Heimdal as the Kerberos 5 implementation.
  * Add smbd max io size parameter.
  * Accept global share options.
- 3.4.4:
  * add smb2 max credits parameter to configuration.
  * add space in ipc req/resp.
- Use git tag tarball instead of GitHub release, due to autogen.sh removal
- Package man pages and move example configuration under docdir
  Tue 18 Jan 2022 11:41:09 UTC - Enzo Matsumiya <ematsumiya@suse.de>
- Update to version 3.4.3:
  * Fix file transfer stuck at 99%%
  * Creates a template ksmbd.service systemd unit file
  * Remove follow symlinks support
  * Throttle session setup failures to avoid dictionary attacks
- Updates to spec file
  * use pkgconfig() for BuildRequires
  * update Source URL to use project's upstream instead of maintainer's
    personal repo
* Wed Sep 29 2021 Enzo Matsumiya <ematsumiya@suse.de>
- Initial import from main repository. Version 3.4.2.
